<?php


/*$mdocInfo
 Author: Hauke Goos-Habermann (HHabermann@pc-kiel.de)
 Description: Class for handling distribtion and desktop profiles.
$*/

class CDDP
{
	private $distributionDesktopProfiles, $baseProfileOptions;


/**
**name CDDP::__construct()
**description Constructor for new CDDP objects.
**/
	public function __construct()
	{
		// Boot, CPU architecture and kernel
		$this->baseProfileOptions['arch'] = 'amd64';
		$this->baseProfileOptions['bootloader'] = 'grub';
		$this->baseProfileOptions['kernel'] = 'linux-image-generic';

		// Language and time
		$this->baseProfileOptions['language'] = 'de';
		$this->baseProfileOptions['timeZone'] = 'Europe/Berlin';
		$this->baseProfileOptions['getSystemtimeByNTP'] = 'yes';

		// Optional features
		$this->baseProfileOptions['buildPoolFromClientDebs'] = '';
		$this->baseProfileOptions['installX2goserver'] = '0';
		$this->baseProfileOptions['installPrinter'] = 'no';

		$this->baseProfileOptions['disableSudoRootLogin'] = '1';
		$this->baseProfileOptions['nfshomeserver'] = '';
		$this->baseProfileOptions['disableSSLCertCheck'] = '0';
		
		$this->baseProfileOptions['addNewLocalLogin'] = 'yes';
		$this->baseProfileOptions['ldaptype'] = 'none';
		$this->baseProfileOptions['ldapserver'] = '';

		$this->baseProfileOptions['packageProxy'] = getServerIP();
		$this->baseProfileOptions['packagePort'] = 2323;
		$this->baseProfileOptions['netRootPwd'] = DB_genPassword(6);

		// Profiles
		$this->distributionDesktopProfiles["Debian 12 KDE"] =
		[
			"sourcename" => "bookworm",
			"desktop" => "Debian8KdeFull"
		];
	
	
// 		parent::__construct();
	}











	/**
	**name CDDP::getProfiles()
	**description Gets all available profiles from the distribution desktop profiles array.
	**returns An array of profile names.
	**/
	public function getProfiles()
	{
		return(array_keys($this->distributionDesktopProfiles));
	}





	/**
	**name CDDP::getProfile($profileName)
	**description Gets a distribution/desktop profile by name.
	**parameter profileName: The name of the profile to get
	**returns The profile data if found, otherwise false.
	**/
	public function getProfile($profileName)
	{
		if (!isset($this->distributionDesktopProfiles[$profileName])) return(false);

		// Merge the base profile settings with the specific
		return(array_merge($this->baseProfileOptions, $this->distributionDesktopProfiles[$profileName]));
	}





	/**
	**name CDDP::setIninstallOptionsAndinstallParams($profileName, &$installOptions, &$installParams)
	**description Sets parameters from the profile in the according $installOptions and $installParams arrays.
	**parameter profileName: The name of the profile to load
	**parameter installOptions: Variable to write the settings to.
	**parameter installParams: Variable to write the settings to.
	**returns true, if the parameters could be set, otherwise false.
	**/
	public function setIninstallOptionsAndinstallParams($profileName, &$installOptions, &$installParams)
	{
		// Load profile
		$profile = $this->getProfile($profileName);

		// Check, if a profile could be loaded
		if (!$profile || !is_array($profile)) return(false);
		
		$installOptions['arch'] = $profile['arch'];
		$installOptions['bootloader'] = $profile['bootloader'];
		$installOptions['kernel'] = $profile['kernel'];

		$installParams['language'] = $profile['language'];
		$installOptions['timeZone'] = $profile['timeZone'];
		$installOptions['getSystemtimeByNTP'] = $profile['getSystemtimeByNTP'];

		$installOptions['buildPoolFromClientDebs'] = $profile['buildPoolFromClientDebs'];
		$installOptions['installX2goserver'] = $profile['installX2goserver'];
		$installOptions['installPrinter'] = $profile['installPrinter'];

		$installOptions['disableSudoRootLogin'] = $profile['disableSudoRootLogin'];
		$installOptions['nfshomeserver'] = $profile['nfshomeserver'];
		$installOptions['disableSSLCertCheck'] = $profile['disableSSLCertCheck'];

		$installOptions['addNewLocalLogin'] = $profile['addNewLocalLogin'];

		$installOptions['distr'] = SRCLST_getValue($profile['sourcename'],"distr");
		$installOptions['release'] = SRCLST_getValue($profile['sourcename'],"release");
		$installOptions['packagesource'] = $profile['sourcename'];
		$installOptions['desktop'] = $profile['desktop'];
		$installOptions['ldaptype'] = $profile['ldaptype'];
		$installOptions['ldapserver'] = $profile['ldapserver'];

		$installOptions['packageProxy'] = $this->baseProfileOptions['packageProxy'];
		$installOptions['packagePort'] = $this->baseProfileOptions['packagePort'];
		$installOptions['netRootPwd'] = $this->baseProfileOptions['netRootPwd'];

		return(true);
	}

}

?>